==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/UpdateRoleAliasResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{RoleAliasArn, RoleAlias}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateRoleAliasResponse(
    roleAlias: Optional[RoleAlias] = Optional.Absent,
    roleAliasArn: Optional[RoleAliasArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse = {
    import UpdateRoleAliasResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
      .builder()
      .optionallyWith(
        roleAlias.map(value => RoleAlias.unwrap(value): java.lang.String)
      )(_.roleAlias)
      .optionallyWith(
        roleAliasArn.map(value => RoleAliasArn.unwrap(value): java.lang.String)
      )(_.roleAliasArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.UpdateRoleAliasResponse.ReadOnly =
    zio.aws.iot.model.UpdateRoleAliasResponse.wrap(buildAwsValue())
}
object UpdateRoleAliasResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.UpdateRoleAliasResponse =
      zio.aws.iot.model.UpdateRoleAliasResponse(
        roleAlias.map(value => value),
        roleAliasArn.map(value => value)
      )
    def roleAlias: Optional[RoleAlias]
    def roleAliasArn: Optional[RoleAliasArn]
    def getRoleAlias: ZIO[Any, AwsError, RoleAlias] =
      AwsError.unwrapOptionField("roleAlias", roleAlias)
    def getRoleAliasArn: ZIO[Any, AwsError, RoleAliasArn] =
      AwsError.unwrapOptionField("roleAliasArn", roleAliasArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
  ) extends zio.aws.iot.model.UpdateRoleAliasResponse.ReadOnly {
    override val roleAlias: Optional[RoleAlias] = zio.aws.core.internal
      .optionalFromNullable(impl.roleAlias())
      .map(value => zio.aws.iot.model.primitives.RoleAlias(value))
    override val roleAliasArn: Optional[RoleAliasArn] = zio.aws.core.internal
      .optionalFromNullable(impl.roleAliasArn())
      .map(value => zio.aws.iot.model.primitives.RoleAliasArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
  ): zio.aws.iot.model.UpdateRoleAliasResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/UpdateRoleAliasResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.{RoleAliasArn, RoleAlias}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateRoleAliasResponse(
    roleAlias: Option[RoleAlias] = None,
    roleAliasArn: Option[RoleAliasArn] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse = {
    import UpdateRoleAliasResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
      .builder()
      .optionallyWith(
        roleAlias.map(value => RoleAlias.unwrap(value): java.lang.String)
      )(_.roleAlias)
      .optionallyWith(
        roleAliasArn.map(value => RoleAliasArn.unwrap(value): java.lang.String)
      )(_.roleAliasArn)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.UpdateRoleAliasResponse.ReadOnly =
    zio.aws.iot.model.UpdateRoleAliasResponse.wrap(buildAwsValue())
}
object UpdateRoleAliasResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.UpdateRoleAliasResponse =
      zio.aws.iot.model.UpdateRoleAliasResponse(
        roleAlias.map(value => value),
        roleAliasArn.map(value => value)
      )
    def roleAlias: Option[RoleAlias]
    def roleAliasArn: Option[RoleAliasArn]
    def getRoleAlias: ZIO[Any, AwsError, RoleAlias] =
      AwsError.unwrapOptionField("roleAlias", roleAlias)
    def getRoleAliasArn: ZIO[Any, AwsError, RoleAliasArn] =
      AwsError.unwrapOptionField("roleAliasArn", roleAliasArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
  ) extends zio.aws.iot.model.UpdateRoleAliasResponse.ReadOnly {
    override val roleAlias: Option[RoleAlias] = scala
      .Option(impl.roleAlias())
      .map(value => zio.aws.iot.model.primitives.RoleAlias(value))
    override val roleAliasArn: Option[RoleAliasArn] = scala
      .Option(impl.roleAliasArn())
      .map(value => zio.aws.iot.model.primitives.RoleAliasArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.UpdateRoleAliasResponse
  ): zio.aws.iot.model.UpdateRoleAliasResponse.ReadOnly = new Wrapper(impl)
}
